@@ -30,10 +30,10 @@ pub type Iter<'a, K, V, P> =
 pub type IterKeys<'a, K, V, P> = core::iter::Map<Iter<'a, K, V, P>, fn((&'a K, &V)) -> &'a K>;
 pub type IterValues<'a, K, V, P> = core::iter::Map<Iter<'a, K, V, P>, fn((&K, &'a V)) -> &'a V>;
 
+#[allow(clippy::cast_possible_truncation)]
 const DEFAULT_DEGREE: u8 = 8 * size_of::<usize>() as u8;
 
-/// Creates a [`HashTrieMap`](map/hash_trie_map/struct.HashTrieMap.html) containing the
-/// given arguments:
+/// Creates a [`HashTrieMap`](crate::HashTrieMap) containing the given arguments:
 ///
 /// ```
 /// # use rpds::*;
@@ -59,8 +59,8 @@ macro_rules! ht_map {
     };
 }
 
-/// Creates a [`HashTrieMap`](map/hash_trie_map/struct.HashTrieMap.html) that
-/// implements `Sync`, containing the given arguments:
+/// Creates a [`HashTrieMap`](crate::HashTrieMap) that implements `Sync`, containing the given
+/// arguments:
 ///
 /// ```
 /// # use rpds::*;
@@ -224,10 +224,13 @@ mod node_utils {
     pub fn index_from_hash(hash: HashValue, depth: usize, degree: u8) -> Option<usize> {
         debug_assert!(degree.is_power_of_two());
 
+        #[allow(clippy::cast_possible_truncation)]
         let shift = depth as u32 * degree.trailing_zeros();
 
+        #[allow(clippy::cast_lossless)]
         if (shift as usize) < 8 * size_of_val(&hash) {
             let mask = degree as HashValue - 1;
+            #[allow(clippy::cast_possible_truncation)]
             Some(((hash >> shift) & mask) as usize)
         } else {
             None
@@ -370,10 +373,7 @@ where
                             let subtree = subtrees.first().unwrap();
 
                             // Keep collision at the bottom of the tree.
-                            match subtree.borrow() {
-                                Node::Leaf(Bucket::Single(_)) => true,
-                                _ => false,
-                            }
+                            matches!(subtree.borrow(), Node::Leaf(Bucket::Single(_)))
                         };
 
                         match compress {
@@ -542,12 +542,10 @@ where
             Bucket::Collision(entries) => {
                 let removed =
                     bucket_utils::list_remove_first(entries, |e| e.matches(key, key_hash));
-                if let Some(e) = removed {
+                removed.and_then(|e| {
                     entries.push_front_mut(e);
                     entries.first_mut()
-                } else {
-                    None
-                }
+                })
             }
         }
     }
@@ -780,7 +778,18 @@ where
     {
         let key_hash = node_utils::hash(key, &self.hasher_builder);
 
-        self.root.get(key, key_hash, 0, self.degree).map(|e| e.value())
+        self.root.get(key, key_hash, 0, self.degree).map(EntryWithHash::value)
+    }
+
+    #[must_use]
+    pub fn get_key_value<Q: ?Sized>(&self, key: &Q) -> Option<(&K, &V)>
+    where
+        K: Borrow<Q>,
+        Q: Hash + Eq,
+    {
+        let key_hash = node_utils::hash(key, &self.hasher_builder);
+
+        self.root.get(key, key_hash, 0, self.degree).map(|e| (e.key(), e.value()))
     }
 
     #[must_use]
@@ -856,7 +865,6 @@ where
         self.size() == 0
     }
 
-    #[must_use]
     pub fn iter(&self) -> Iter<'_, K, V, P> {
         self.iter_ptr().map(|e| (&e.key, &e.value))
     }
@@ -866,12 +874,10 @@ where
         IterPtr::new(self)
     }
 
-    #[must_use]
     pub fn keys(&self) -> IterKeys<'_, K, V, P> {
         self.iter().map(|(k, _)| k)
     }
 
-    #[must_use]
     pub fn values(&self) -> IterValues<'_, K, V, P> {
         self.iter().map(|(_, v)| v)
     }
@@ -894,7 +900,7 @@ where
         let key_hash = node_utils::hash(key, &self.hasher_builder);
         SharedPointer::make_mut(&mut self.root)
             .get_mut(key, key_hash, 0, self.degree)
-            .map(|e| e.value_mut())
+            .map(EntryWithHash::value_mut)
     }
 }
 
