@@ -23,8 +23,7 @@ pub type RangeIter<'a, K, V, RB, Q, P> = core::iter::Map<
     fn(&'a SharedPointer<Entry<K, V>, P>) -> (&'a K, &'a V),
 >;
 
-/// Creates a [`RedBlackTreeMap`](map/red_black_tree_map/struct.RedBlackTreeMap.html) containing the
-/// given arguments:
+/// Creates a [`RedBlackTreeMap`](crate::RedBlackTreeMap) containing the given arguments:
 ///
 /// ```
 /// # use rpds::*;
@@ -50,8 +49,8 @@ macro_rules! rbt_map {
     };
 }
 
-/// Creates a [`RedBlackTreeMap`](map/red_black_tree_map/struct.RedBlackTreeMap.html) that
-/// implements `Sync`, containing the given arguments:
+/// Creates a [`RedBlackTreeMap`](crate::RedBlackTreeMap) that implements `Sync`, containing the
+/// given arguments:
 ///
 /// ```
 /// # use rpds::*;
@@ -235,14 +234,14 @@ where
     ///        a  ┌───┐                                       ╲ ╲
     ///           │ y │                                        ╲ ╲             ┌───┐
     ///           └───┘                                         ╲ ╲            │ y │
-    ///            ╱ ╲                                           ╲  ┃          └───┘
+    ///            ╱ ╲                                           ╲  │          └───┘
     ///           b   c                                          ───┘           ╱ ╲
     ///                                                                        ╱   ╲
     ///                                                                   ┏━━━┓     ┏━━━┓
     ///                                                                   ┃ x ┃     ┃ z ┃
     ///            ┏━━━┓                                                  ┗━━━┛     ┗━━━┛
     ///            ┃ x ┃                                         ───┐      ╱ ╲       ╱ ╲
-    ///            ┗━━━┛                                         ╱  ┃     ╱   ╲     ╱   ╲
+    ///            ┗━━━┛                                         ╱  │     ╱   ╲     ╱   ╲
     ///             ╱ ╲                                         ╱ ╱      a     b   c     d
     ///            a  ┌───┐                                    ╱ ╱
     ///               │ z │                                   ╱ ╱
@@ -383,8 +382,8 @@ where
             is_root: bool,
         ) -> bool {
             match node {
-                Some(n) => {
-                    let node = SharedPointer::make_mut(n);
+                Some(node) => {
+                    let node = SharedPointer::make_mut(node);
 
                     let ret = match k.cmp(&node.entry.key) {
                         Ordering::Less => {
@@ -725,8 +724,8 @@ where
             P: SharedPointerKind,
         {
             let (removed, make_node_none) = match *node {
-                Some(ref mut node_ptr) => {
-                    let node = SharedPointer::make_mut(node_ptr);
+                Some(ref mut node) => {
+                    let node = SharedPointer::make_mut(node);
 
                     let ret = match k.cmp(node.entry.key.borrow()) {
                         Ordering::Less => (del_left(node, k), false),
@@ -823,6 +822,15 @@ where
         self.root.as_ref().and_then(|r| r.get(key)).map(|e| &e.value)
     }
 
+    #[must_use]
+    pub fn get_key_value<Q: ?Sized>(&self, key: &Q) -> Option<(&K, &V)>
+    where
+        K: Borrow<Q>,
+        Q: Ord,
+    {
+        self.root.as_ref().and_then(|r| r.get(key)).map(|e| (&e.key, &e.value))
+    }
+
     #[must_use]
     pub fn first(&self) -> Option<(&K, &V)> {
         self.root.as_ref().map(|r| r.first()).map(|e| (&e.key, &e.value))
@@ -904,7 +912,6 @@ where
         self.size() == 0
     }
 
-    #[must_use]
     pub fn iter(&self) -> Iter<'_, K, V, P> {
         self.iter_ptr().map(|e| (&e.key, &e.value))
     }
@@ -914,17 +921,14 @@ where
         IterPtr::new(self)
     }
 
-    #[must_use]
     pub fn keys(&self) -> IterKeys<'_, K, V, P> {
         self.iter().map(|(k, _)| k)
     }
 
-    #[must_use]
     pub fn values(&self) -> IterValues<'_, K, V, P> {
         self.iter().map(|(_, v)| v)
     }
 
-    #[must_use]
     pub fn range<Q, RB>(&self, range: RB) -> RangeIter<'_, K, V, RB, Q, P>
     where
         K: Borrow<Q>,
