@@ -1378,6 +1378,18 @@ fn test_macro_rbt_map() {
     assert_eq!(set_1_2_3, rbt_map![1 => 2, 2 => 3, 3 => 4]);
 }
 
+#[test]
+fn test_get_key_value() {
+    let mut map = RedBlackTreeMap::new();
+
+    map = map.insert("foo", 4);
+    assert_eq!(map.get_key_value("foo"), Some((&"foo", &4)));
+
+    map = map.insert("bar", 2);
+    assert_eq!(map.get_key_value("foo"), Some((&"foo", &4)));
+    assert_eq!(map.get_key_value("bar"), Some((&"bar", &2)));
+}
+
 #[test]
 fn test_insert_simple() {
     let mut map = RedBlackTreeMap::new();
