@@ -19,7 +19,7 @@ pub type Iter<'a, T, P> = core::iter::Map<IterPtr<'a, T, P>, fn(&SharedPointer<T
 
 const DEFAULT_BITS: u8 = 5;
 
-/// Creates a [`Vector`](vector/struct.Vector.html) containing the given arguments:
+/// Creates a [`Vector`](crate::Vector) containing the given arguments:
 ///
 /// ```
 /// # use rpds::*;
@@ -45,8 +45,7 @@ macro_rules! vector {
     };
 }
 
-/// Creates a [`Vector`](vector/struct.Vector.html) that implements `Sync`, containing the given
-/// arguments:
+/// Creates a [`Vector`](crate::Vector) that implements `Sync`, containing the given arguments:
 ///
 /// ```
 /// # use rpds::*;
@@ -162,7 +161,7 @@ where
 
                 match a.get_mut(b) {
                     Some(subtree) => {
-                        SharedPointer::make_mut(subtree).assoc(value, height - 1, bucket)
+                        SharedPointer::make_mut(subtree).assoc(value, height - 1, bucket);
                     }
                     None => {
                         let mut subtree = if height > 1 {
@@ -418,17 +417,17 @@ where
 
             match new_root {
                 Node::Branch(ref mut values) => values.push(SharedPointer::clone(&self.root)),
-                _ => unreachable!("expected a branch"),
+                Node::Leaf(_) => unreachable!("expected a branch"),
             }
 
             let length = self.length;
             self.root = SharedPointer::new(new_root);
             self.length += 1;
 
-            self.assoc(length, v)
+            self.assoc(length, v);
         } else {
             let length = self.length;
-            self.assoc(length, v)
+            self.assoc(length, v);
         }
     }
 
@@ -490,7 +489,6 @@ where
         self.len() == 0
     }
 
-    #[must_use]
     pub fn iter(&self) -> Iter<'_, T, P> {
         self.iter_ptr().map(|v| v.borrow())
     }
@@ -688,17 +686,22 @@ where
     P: SharedPointerKind,
 {
     fn new(node: &Node<T, P>, backwards: bool) -> IterStackElement<'_, T, P> {
+        #[allow(clippy::cast_possible_wrap)]
         IterStackElement { node, index: if backwards { node.used() as isize - 1 } else { 0 } }
     }
 
+    #[inline]
     fn current_node(&self) -> &'a Node<T, P> {
+        #[allow(clippy::cast_sign_loss)]
         match self.node {
             Node::Branch(a) => a[self.index as usize].as_ref(),
             Node::Leaf(_) => panic!("called current node of a branch"),
         }
     }
 
+    #[inline]
     fn current_elem(&self) -> &'a SharedPointer<T, P> {
+        #[allow(clippy::cast_sign_loss)]
         match self.node {
             Node::Leaf(a) => &a[self.index as usize],
             Node::Branch(_) => panic!("called current element of a branch"),
@@ -708,6 +711,7 @@ where
     /// Advance and returns `true` if finished.
     #[inline]
     fn advance(&mut self, backwards: bool) -> bool {
+        #[allow(clippy::cast_sign_loss)]
         if backwards {
             self.index -= 1;
             self.index < 0
@@ -782,7 +786,7 @@ where
 
     #[inline]
     fn current(stack: &[IterStackElement<'a, T, P>]) -> Option<&'a SharedPointer<T, P>> {
-        stack.last().map(|e| e.current_elem())
+        stack.last().map(IterStackElement::current_elem)
     }
 
     #[inline]
